@@ -18,6 +18,7 @@ from omegaconf import OmegaConf, open_dict, DictConfig
 from pathlib import Path
 from typing import Callable, Dict
 import collections.abc
+from functools import lru_cache
 
 log = logging.getLogger(__name__)
 
@@ -296,6 +297,7 @@ class FederatedPipelineBase(AMLPipelineHelper):
     def build(self, config: DictConfig):
         """Constructs the federated pipeline. User does not need to modify."""
 
+        @lru_cache(maxsize=None)
         @dsl.pipeline(display_name=self.create_subgraph_name())
         def _subpipeline_function(**kwargs):
             cool_name = self.create_base_name()
