@@ -34,6 +34,7 @@ class module_reference:
 @dataclass
 class module_manifest:
     manifest: List[module_reference] = field(default_factory=list)
+    feeds: List[str] = field(default_factory=list)
     registries: List[str] = field(default_factory=list)
 
 
@@ -107,6 +108,7 @@ class AMLModuleLoader:
         )
         self.module_cache = {}
 
+        self.feeds: List[str] = []
         self.registries: List[str] = []
 
         # internal manifest built from yaml config
@@ -139,6 +141,9 @@ class AMLModuleLoader:
 
             self.modules_manifest[module_key] = entry
 
+        for feed in config.modules.get("feeds", []):
+            self.feeds.append(feed)
+
         for registry in config.modules.get("registries", []):
             self.registries.append(registry)
 
@@ -261,7 +266,21 @@ class AMLModuleLoader:
                 return loaded_module_class
 
             except BaseException as e:
-                log.warning(f"Exception: {e}")
+                log.debug(f"Exception: {e}")
+
+        for feed in self.feeds:
+            try:
+                log.info(f"Loading component {module_name} from feed {feed}")
+                loaded_module_class = Component.load(
+                    current_workspace(),
+                    name=f"azureml.feed://{feed}/{module_name}",
+                    version=module_version,
+                )
+                self.put_in_cache(module_cache_key, loaded_module_class)
+                return loaded_module_class
+
+            except BaseException as e:
+                log.debug(f"Exception: {e}")
 
         try:
             # try without namespace first
