@@ -36,6 +36,8 @@ class pipeline_cli_config:  # pylint: disable=invalid-name
     - `publish` (bool): set to True to publish the pipeline to Azure ML as an endpoint (default to False)
     - `endpoint_name` (Optional[str]): name of the endpoint in which to publish the pipeline
     - `endpoint_description` (Optional[str]): description of the endpoint in which to publish the pipeline
+    - `log_error_only` （bool): set to True for logging error only (default to False)
+    - `skip_validation` (bool): set to True to not run pipeline.validate() after building and submit with "skip_validation=True" (default to False)
     """
 
     regenerate_outputs: bool = False
@@ -57,6 +59,8 @@ class pipeline_cli_config:  # pylint: disable=invalid-name
     publish: bool = False
     endpoint_name: Optional[str] = None
     endpoint_description: Optional[str] = None
+    log_error_only: bool = False
+    skip_validation: bool = False
 
 
 @dataclass
