@@ -17,11 +17,9 @@ import shutil
 import yaml
 import jsonpath_ng
 from typing import Callable
-from hashlib import sha256
-from pathlib import Path
 from toposort import toposort_flatten
 import datetime
-
+from functools import lru_cache, wraps
 
 try:
     import hydra
@@ -36,11 +34,6 @@ try:
     from azureml.core import Dataset
     from azureml.pipeline.core import PipelineRun
     from azure.ml.component.component import Component, Input, Output
-    from azure.ml.component._core._component_definition import (
-        ComponentDefinition,
-        ComponentType,
-    )
-    from azure.ml.component.pipeline import PipelineParameter
     from azureml.exceptions._azureml_exception import UserErrorException
 except ImportError as error:
     raise ImportError(
@@ -55,9 +48,6 @@ from shrike.pipeline.pipeline_config import default_config_dict, HDI_DEFAULT_CON
 from shrike.pipeline.telemetry_utils import TelemetryLogger
 from shrike._core import is_eyesoff_helper
 
-from functools import wraps
-from functools import lru_cache
-
 
 log = logging.getLogger(__name__)
 
@@ -145,10 +135,12 @@ class AMLPipelineHelper:
     ### USER FACING HELPER METHODS ###
     ##################################
 
+    @lru_cache(maxsize=None)
     def workspace(self):
         """Gets the current workspace"""
         return current_workspace()
 
+    @lru_cache(maxsize=None)
     def component_load(self, component_key) -> Callable[..., "Component"]:
         """Loads one component from the manifest"""
         component_func = self.module_loader.load_module(
@@ -167,6 +159,7 @@ class AMLPipelineHelper:
 
         return wrapper
 
+    @lru_cache(maxsize=None)
     def module_load(self, module_key):
         """Loads one module from the manifest"""
         module_func = self.module_loader.load_module(
@@ -181,6 +174,7 @@ class AMLPipelineHelper:
 
         return wrapper
 
+    @lru_cache(maxsize=None)
     def subgraph_load(self, subgraph_key, custom_config=OmegaConf.create()) -> Callable:
         """Loads one subgraph from the manifest
         Args:
@@ -205,6 +199,7 @@ class AMLPipelineHelper:
         # subgraph_instance.setup(self.pipeline_config)
         return subgraph_instance.build(subgraph_config)
 
+    @lru_cache(maxsize=None)
     def dataset_load(
         self,
         name,
@@ -1035,11 +1030,16 @@ class AMLPipelineHelper:
                 f"During build() of graph class {self.__class__.__name__}, call to self.apply_recommended_runsettings() is wrong: key used as first argument ('{module_key}') maps to a module reference {module_manifest_entry} which name is different from the module instance provided as 2nd argument (name={module_instance.name}), did you use the wrong module key as first argument?"
             )
 
-    @lru_cache(maxsize=128)
+    @lru_cache(maxsize=None)
     def _get_component_name_from_instance(self, component_instance):
-        """We need to have this _get_component_name_from_instance() to get component name for apply_smart_runsettings(),
-        and can't simply use "component_name = component_instance.name". Otherwise apply_smart_runsettings() might work incorrectly for local
-        components. See more detailed explanation and examples here: https://github.com/Azure/shrike/issues/411"""
+        """
+        We need to have this `_get_component_name_from_instance()` to get
+        component name for `apply_smart_runsettings()`, and can't simply use
+        `component_name = component_instance.name`. Otherwise
+        `apply_smart_runsettings()` might work incorrectly for local
+        components. See more detailed explanation and examples here:
+        https://github.com/Azure/shrike/issues/411
+        """
         component_manifest_list = self.config.modules.manifest
         component_name = component_instance.name
         for component_manifest_entry in component_manifest_list:
@@ -1651,8 +1651,9 @@ class AMLPipelineHelper:
         log.info("Overriding compute target if upstream steps use HDI DC...")
         pipeline = self._update_hdi_dc_configs(pipeline)
 
-        log.info("Validating...")
-        pipeline.validate(workspace=current_workspace())
+        if not self.config.run.skip_validation:
+            log.info("Validating...")
+            pipeline.validate(workspace=current_workspace())
 
         if self.config.run.export:
             log.info(f"Exporting to {self.config.run.export}...")
@@ -1681,6 +1682,7 @@ class AMLPipelineHelper:
                 default_compute_target=self.config.compute.default_compute_target,
                 regenerate_outputs=self.config.run.regenerate_outputs,
                 continue_on_step_failure=self.config.run.continue_on_failure,
+                skip_validation=self.config.run.skip_validation,
             )
 
             # Forece pipeline_run to be of the class "azureml.pipeline.core.PipelineRun"
@@ -1704,6 +1706,8 @@ class AMLPipelineHelper:
         # set logging level
         if self.config.run.verbose:
             logging.getLogger().setLevel(logging.DEBUG)
+        elif self.config.run.log_error_only:
+            logging.getLogger().setLevel(logging.ERROR)
 
         # Log the telemetry information in the Azure Application Insights
         try:
