@@ -38,7 +38,10 @@ def component_spec_yaml_exists_and_is_parsable(component_spec_path):
     # opens file for testing schema
     with open(component_spec_path, "r") as ifile:
         component_spec_content = ifile.read()
-        if "$schema: http://azureml/" in component_spec_content:
+        if (
+            "$schema: http://" in component_spec_content
+            or "$schema: https://" in component_spec_content
+        ):
             use_component_sdk = True
         else:
             use_component_sdk = False
